Generate the setup
==================

See `Generating the setup with pyquickhelper <http://www.xavierdupre.fr/app/pyquickhelper/helpsphinx/generatesetup.html>`_.

Extensions to install
+++++++++++++++++++++

* `pyquickhelper <https://pypi.python.org/pypi/pyquickhelper/>`_
